@@ -1,7 +1,7 @@
 from fmn.consumer.backends.base import BaseBackend
 import fedmsg.meta
 
-from kitchen.text.converters import to_bytes
+from kitchen.text.converters import to_bytes, to_unicode
 
 import datetime
 import smtplib
@@ -44,17 +44,15 @@ class EmailBackend(BaseBackend):
             return
 
         email_message = email.Message.Message()
-        to_addr = ('utf-8', None, to_bytes(recipient['email address']))
-        email_message.add_header('To', to_addr)
-        from_addr = ('utf-8', None, to_bytes(self.from_address))
-        email_message.add_header('From', from_addr)
+        email_message.add_header('To', to_bytes(recipient['email address']))
+        email_message.add_header('From', to_bytes(self.from_address))
 
         subject_prefix = self.config.get('fmn.email.subject_prefix', '')
         if subject_prefix:
             subject = '{0} {1}'.format(
                 subject_prefix.strip(), subject.strip())
 
-        email_message.add_header('Subject', ('utf-8', None, to_bytes(subject)))
+        email_message.add_header('Subject', to_bytes(subject))
 
         # Since we do simple text email, adding the footer to the content
         # before setting the payload.
@@ -67,7 +65,7 @@ class EmailBackend(BaseBackend):
         if footer:
             content += u'\n\n--\n{0}'.format(footer.strip())
 
-        email_message.set_payload(('utf-8', None, to_bytes(content)))
+        email_message.set_payload(to_bytes(content))
 
         server = smtplib.SMTP(self.mailserver)
         try:
@@ -84,16 +82,18 @@ class EmailBackend(BaseBackend):
         self.log.debug("Email sent")
 
     def handle(self, session, recipient, msg):
-        content = fedmsg.meta.msg2repr(msg, **self.config)
+        link = fedmsg.meta.msg2link(msg, **self.config)
+        content = fedmsg.meta.msg2long_form(msg, **self.config)
         subject = fedmsg.meta.msg2subtitle(msg, **self.config)
 
-        self.send_mail(session, recipient, subject, content)
+        self.send_mail(session, recipient, subject, content + "\n\t" + link)
 
     def handle_batch(self, session, recipient, queued_messages):
         def _format_line(msg):
             timestamp = datetime.datetime.fromtimestamp(msg['timestamp'])
-            payload = fedmsg.meta.msg2repr(msg, **self.config)
-            return timestamp.strftime("%c") + ", " + payload
+            link = fedmsg.meta.msg2link(msg, **self.config)
+            payload = fedmsg.meta.msg2long_form(msg, **self.config)
+            return timestamp.strftime("%c") + ", " + payload + "\n\t" + link
 
         n = len(queued_messages)
         subject = u"Fedora Notifications Digest (%i updates)" % n
